import { useState, useEffect } from "react"
import { User } from "../types"
import { Link } from "react-router-dom"
import axios from "axios"
import TopBar from "../components/TopBar"

export default function EditProfile() {
    const [token, setToken] = useState<string>("");
    const [user, setUser] = useState<User>();
    const [description, setDescription] = useState<string>("");

    useEffect(() => {
        const localToken = localStorage.getItem("token");
        if (localToken) {
            setToken(localToken)

            axios
                .post("/api/auth/me", { token: localToken })
                .then((res) => {
                    setUser(res.data);
                });
        }
    }, []);

    function uploadPfp(e: React.FormEvent) {
        e.preventDefault();

        const formData = new FormData();
        const fileInput = document.getElementById("pfp") as HTMLInputElement;
        if (fileInput.files) {
            formData.append("pfp", fileInput.files[0]);
        }
        formData.append("token", token);
        axios
            .post("/api/auth/me/uploadpfp", formData, { 
                headers: {
                    "Content-Type": "multipart/form-data",
                },
            })
            .then(() => {
                window.location.reload();
            })
            .catch((err) => {
                console.error(err.response.data);
            });
    }

    function deletePfp(e: React.FormEvent) {
        e.preventDefault();
        axios
            .post("/api/auth/me/deletepfp", { token: token })
            .then(() => {
                window.location.reload();
            })
            .catch((err) => {
                console.error(err.response.data);
            });
    }

    function editUsername(e: React.FormEvent) {
        e.preventDefault();
        const newUsername = (document.getElementById("username") as HTMLInputElement).value;
        axios
            .post("/api/auth/me/setusername", { token: token, username: newUsername })
            .then(() => {
                window.location.reload();
            })
            .catch((err) => {
                console.error(err.response.data);
            });
    }

    function editPassword(e: React.FormEvent) {
        e.preventDefault();
        const oldPassword = (document.getElementById("old-password") as HTMLInputElement).value;
        const newPassword = (document.getElementById("password") as HTMLInputElement).value;
        const confirmPassword = (document.getElementById("confirm-password") as HTMLInputElement).value;
        if (newPassword !== confirmPassword) {
            alert("Passwords do not match");
            return;
        }
        axios
            .post("/api/auth/me/setpassword", { token: token, oldPassword: oldPassword, password: newPassword })
            .then(() => {
                window.location.reload();
            })
            .catch((err) => {
                console.error(err.response.data);
            });
    }

    function editDescription(e: React.FormEvent) {
        e.preventDefault();
        axios
            .post("/api/auth/me/setdescription", { token: token, description: description })
            .then(() => {
                window.location.reload();
            })
            .catch((err) => {
                console.error(err.response.data);
            });
    }

    if (!user) {
        return (
            <div className="forum-page">
                <TopBar user={user}/>
                <div className="forum-section">
                    <p>Please log in to edit your profile</p>
                    <Link to="/login">Login</Link>
                </div>
            </div>
        )
    }

    return (
        <div className="forum-page">
            <TopBar user={user}/>
            <div className="forum-section">
                <h2>Edit Profile Picture</h2>
                <form className="form-horizontal">
                    <label htmlFor="pfp">
                        <span className="forum-button">Upload new profile picture</span>
                        <input type="file" name="pfp" id="pfp" accept="image/*" />
                    </label>
                    <button onClick={uploadPfp} className="forum-button">Save</button>
                    <button onClick={deletePfp} className="forum-button">Delete</button>
                </form>
            </div>
            <div className="forum-section">
                <h2>Edit Username</h2>
                <form className="form-horizontal">
                    <input type="text" name="username" id="username"  placeholder={user?.username}  className="forum-input" />
                    <button onClick={editUsername} className="forum-button">Save</button>
                </form>
            </div>
            <div className="forum-section">
                <h2>Edit description</h2>
                <form className="form-horizontal">
                    <textarea
                        name="description"
                        id="description"
                        placeholder={user?.description}
                        className="forum-input"
                        value={description}
                        onChange={(e) => setDescription(e.target.value)}
                    />
                    <button onClick={editDescription} className="forum-button">Save</button>
                </form>
            </div>
            <div className="forum-section">
                <h2>Edit Password</h2>
                <form className="form-horizontal">
                    <input type="password" name="old-password" id="old-password" placeholder="Old password" className="forum-input" />
                    <input type="password" name="password" id="password" placeholder="New password" className="forum-input" />
                    <input type="password" name="confirm-password" id="confirm-password" placeholder="Confirm new password" className="forum-input" />
                    <button onClick={editPassword} className="forum-button">Save</button>
                </form>
            </div>
        </div>
    )
}