import axios from "axios";
import { useState } from "react";
import { useNavigate, Link } from "react-router-dom";
import TopBar from "../components/TopBar";

export default function Register () {
    const [username, setUsername] = useState("");
    const [password, setPassword] = useState("");
    const navigate = useNavigate();

    function handleSubmit(e: React.FormEvent) {
        e.preventDefault();
        axios
            .post("/api/auth/register", { username, password }).then(() => {
                axios
                    .post("/api/auth/login", { username, password })
                    .then((res) => {
                        localStorage.setItem("token", res.data.token);
                        navigate("/");
                    })
                    .catch(() => {
                        alert("Register failed");
                    }
                );
            })
            .catch((err) => {
                alert(err.response);
            });
    }

    return (
        <div className="forum-page">
            <TopBar user={undefined}/>
            <div className="forum-section center">
                <h2>Register</h2>
                <form onSubmit={handleSubmit} className="form-vertical">
                    {!/^[a-zA-Z0-9-_]+$/.test(username) && username.length != 0 && (
                        <p>Username can only contain letters, numbers, - and _</p>
                    )}
                    <input
                        className="forum-input"
                        type="text"
                        placeholder="Username"
                        value={username}
                        onChange={(e) => setUsername(e.target.value)}
                    />
                    <input
                        className="forum-input"
                        type="password"
                        placeholder="Password"
                        value={password}
                        onChange={(e) => setPassword(e.target.value)}
                    />
                    <button type="submit" disabled={!/^[a-zA-Z0-9-_]+$/.test(username)} className="forum-button">
                        Register
                    </button>
                </form>
                <Link to="/login">Login</Link>
            </div>
        </div>
    );
}